@@ -11,14 +11,12 @@ from pistil.worker import Worker
 
 class MyWorker(Worker):
 
-    def run(self):
-
-        while True:
-            print "hello from worker n°%s" % self.pid
-            time.sleep(1)
+    def handle(self):
+        print "hello from worker n°%s" % self.pid
 
 
 if __name__ == "__main__":
-    conf = {"num_workers": 3}
-    a = Arbiter(conf, MyWorker)
+    conf = {}
+    specs = [(MyWorker, 30, "worker", {}, "test")]
+    a = Arbiter(conf, specs)
     a.run()
